SOURCES = [
    dict(name='Amplitude'),
    dict(name='BigQuery'),
    dict(name='Google Search Console'),
    dict(name='MySQL'),
    dict(name='PostgreSQL'),
    dict(name='Redshift'),
    dict(name='Salesforce'),
    dict(name='Stripe'),
]
